% EDITUPD
% Update pressure model from edit menu
% sub-function called by fuzzPRES
%
% trd	training data
% mfs	membership functions
% rls	rule matrix
% rm	rule to remove (if rm=0, no rules are removed)
% mt	mfs type	(if mt=0, mfs type is not changed)
% ct	fuzzy syst.type
% rlimits	domain limits
%
% see fuzzPRES

% M. Setnes, 1998

p=[];

% Check if MFS editor is used
if(mfedit)
   rm=0;	% do not remove rules (in case user forget to set rm=0)
   % get the new MFS from the editors
   mfs(1:mp,:)=mfget(rules);
   mfs(mp+1:mp+mu,:)=mfget(simulate);
   % Are various mfs types used
   mfedit=find(mfs(:,1)~=mfs(1,1));	%re-use mfedit variable
   if ~isempty(mfedit),
      mt=0; % do not change mfs types
   end;
end;   

%------------
% Remove rule
%------------
if(rm~=0) & (rm <=size(rls,1)),
	rls=rls(:,2:size(rls,2));	% remove weights
	set_rem=rls(rm,:);		% sets used in removed rule
	set_rem=sort(set_rem(:));
	set_rem=set_rem(find([1;diff(set_rem)]));
	rls(rm,:)=[];				% remove rule
	% Check if some sets are no longer used (can be removed)
	for i=1:size(set_rem,1),
		if isempty(find(rls==set_rem(i))),
			rls(find(rls>set_rem(i)))=rls(find(rls>set_rem(i)))-1;	% decrease rls indexes
            mfs(set_rem(i),:)=[];		% remove mfs values
			set_rem=set_rem-1;
		end;
	end;
	rls=[ones(size(rls(:,1))),rls];	%add weights
end;	

%----------------
% Update MFS type
%----------------
if(mt~=0)
	mfs(:,1)=mt*ones(size(mfs(:,1)));
end;

%------------------------------
% Update # membership functions
%------------------------------
mp=max(rls(:,2));
mu=max(rls(:,3))-mp;

%-------------------------
% Estimate the CONSEQUENTS
%-------------------------
if (ct==2),	% TAKAGI SUGENO
	dof = dofprod(rls,mfs,trd(:,1:2));
	[p] = suglms([trd(:,1:2) ones(size(trd,1),1)],trd(:,3),dof);
else		% MAMDANI
	dof=dofmin(rls,mfs,trd(:,1:2));
	y=trd(:,3)*ones(1,size(dof,2));
	y=(sum(dof.*y))./(sum(dof)+1e-15);	% gives the singleton cons of all rules
	% Which pressure mfs corresps the most to the y's
	y=mgrade(y,mfs(1:mp,:));
	rmy=[];
	for i=1:size(y,2)
		index=find(y(:,i)==max(y(:,i)));
		rmy=[rmy;index(1)];
	end;
	rls=[rls(:,1:3),rmy];	% Mamdani rule base
end;

% Clean up workspace
clear rmy y dof;

% reset flag
mfedit=0;
% Reset EDIT menu
presedit;