function string = mat2str(matrix);
%MAT2STR Converts a matrix to a string using full precision.
%	
%	STR = MAT2STR(MAT) converts the matrix MAT to a MATLAB
%	string using full precision. 
%
%	See also NUM2STR.

%	Copyright (c) 1990-94 by The MathWorks, Inc.
%	D.Packer 7-10-90
%	Revised, A.Grace, 10-29-90
%       Revised, A.Potvin  9-21-92

string=[];
if isstr(matrix),
   string = matrix;
   return
end

[rows, cols] = size(matrix);
if rows*cols ~= 1
	string = '[';
end
for i = 1:rows
	for j = 1:cols
		if(matrix(i,j) == Inf)
		    string = [string,'Inf'];
		elseif (matrix(i,j) == -Inf)
		    string = [string,'-Inf'];
		else
		    form = '%.15g';
		    string = [string,sprintf(form,real(matrix(i,j)))];
		    if(imag(matrix(i,j)) < 0)
		        string = [string,'-i*',sprintf(form,abs(imag(matrix(i,j))))];
		    elseif(imag(matrix(i,j)) > 0)
		        string = [string,'+i*',sprintf(form,imag(matrix(i,j)))];
		    end
		    string = [string,' '];
		end
	end
	string = [string,';'];
end
if (rows == 0) string = [string, ' ']; end
if rows * cols ~= 1
	string(length(string))  = ']';
else
	string(length(string))  = [];
end
if(length(string)>255)
        disp('Warning string more than 255 characters long');
end
