% PRESINSP
% Inspect the current fuzzy system
% Used in the Pressure Dynamics Exercise
% 
% Plots the fuzzy sets and the model surface
% Prints rule text
% 
% Called by fuzzPRES

% Magne, 1998

% -----------
% Ling Labels
%------------
plabels=pointers(mp,:);
plabels=plabels(find(plabels));
plabels=PLABELS(plabels,:);
ulabels=pointers(mu,:);
ulabels=ulabels(find(ulabels));
ulabels=ULABELS(ulabels,:);

ydom=rlimits(1,1):(rlimits(1,2)-rlimits(1,1))/100:rlimits(1,2);
udom=rlimits(2,1):(rlimits(2,2)-rlimits(2,1))/100:rlimits(2,2);

%--------------------------
% Plot MEMBERSHIP FUNCTIONS
%--------------------------
figure(illustr);clf;
pos=uright;
set(illustr,'Name','Current Model - Fuzzy Sets','Position',pos,'visible','on');

% Plot pressure MFS
subplot(211);
mfplot(ydom,mfs(1:mp,:));
set(gca,'box','off');
axis([rlimits(1,1),rlimits(1,2),0,1]);
xlabel('Pressure y [10e5 Pa]');
ylabel('Membership');
text([(mfs(1:mp,2)+mfs(1:mp,3))/2] ,[0.8*ones(mp,1)],plabels,'FontSize',12);
% clean up workspace
clear ydom;

% Plot valve MFS
subplot(212);
mfplot(udom,mfs(mp+1:mp+mu,:));
set(gca,'box','off');
axis([rlimits(2,1),rlimits(2,2),0,1]);
xlabel('Valve u [% closed]');
ylabel('Membership');
text([(mfs(mp+1:mp+mu,2)+mfs(mp+1:mp+mu,3))/2] ,[0.8*ones(mu,1)],ulabels,'FontSize',12);
% clean up workspace
clear udom;

%--------------------- 
% Plot CONTROL Surface
%---------------------
% Make the antecedent space mesh
P=1:(1.15/25):2.15;
U=0:4:100;
[P,U]=meshgrid(P,U);
if(ct==2),
   dof=dofprod(rls(:,1:3),mfs,[P(:),U(:)]);
   ym=sugval(p,[P(:),U(:),ones(size(P(:)))],dof);
else,
	ym=infer(rls,mfs,[P(:),U(:)]);
end;
figure(simulate);clf;
pos=lright;
meshz(U,P,reshape(ym,size(U,1),size(U,2)));
axis([0 100 1 2.15 min(ym(:)) max(ym(:))]);
view(322,55); 
xlabel('Valve u(k) [% closed]'); ylabel('Pressure y(k)'); 
zlabel('Pressure y(k+1)');
set(simulate,'position',pos,'Name','Current Model - Mapping','visible','on');
% clean up workspace
clear U P dof ym;

%-------------------
% Plot the rules
%-------------------
if(ct==1),	% MAMDANI
	txt=fuzz2txt(rls,str2mat('Pressure','Valve'),['y(k+1)'],[mp;mu;mp],[plabels;ulabels;plabels]);
else,			% TAKAGI-SUGENO
   % must make TS labels
   tslabels=[];
   p_old=p;
	p=p*1e3;
   p=round(p);
   p=p*1e-3;
   for i=1:size(p,1)
      pp=[num2str(p(i,1),3) '*y(k) + ' num2str(p(i,2),3) '*u(k) + ' num2str(p(i,3),3)];
		tslabels=str2mat(tslabels,pp);      
   end;
   tslabels(1,:)=[];
   p=p_old;
   txt=fuzz2txt([rls(:,1:3),[[1:size(rls,1)]+max(rls(:))]'],str2mat('Pressure','Valve'),['y(k+1)'],[mp;mu;size(rls,1)],str2mat(plabels,ulabels,tslabels));
end;
% clean up workspace
clear pp p_old;

pos=lleft;
figure(rules);clf;
set(rules,'Position',pos,'Name','Current Model - RULES','visible','on');
set(gca,'position',[0 0 1 1]);
axis off;
pos_dec=1/(size(rls,1)+1);
pos=1-pos_dec/2;
for i=1:size(rls,1),
   text(0.01,pos,txt(i,:),'fontsize',10);
	pos=pos-pos_dec;   
end;
% clean up workspace
clear pos pos_dec;