function [mfs,rls,p]=presupd(trd,mu,mp,mt,ct,rlimits)
%  [mfs,rls,p]=presupd(trd,mu,mp,mt,ct,rlimits)
% Update pressure model
% sub-function called by fuzzPRES
%
% trd	training data
% mu	# mfs for valve
% mp	# mfs for pressure
% mt	mfs type
% ct	fuzzy syst.type
% rlimits	domain limits
%
% see fuzzPRES

% M. Setnes, 1998

p=[];
% Make membership functions
ss=.1;	% 10% shoulder size
dom=[rlimits(1,1),rlimits(1,1)+ss*(rlimits(1,2)-rlimits(1,1)),rlimits(1,2)-ss*(rlimits(1,2)-rlimits(1,1)),rlimits(1,2)];
mfsp=mfequ(dom,mt,mp);
dom=[rlimits(2,1),rlimits(2,1)+ss*(rlimits(2,2)-rlimits(2,1)),rlimits(2,2)-ss*(rlimits(2,2)-rlimits(2,1)),rlimits(2,2)];
mfsu=mfequ(dom,mt,mu);
mfs=[mfsp;mfsu];

% Make RLS matrix
rmp=ones(1,mu)'*[1:mp];
rmu=([1:mu]'*ones(1,mp))+mp;
rls = [ones((mp*mu),1),rmp(:),rmu(:)];

% IDENTIFY THE CONSEQUENTS
if (ct==2),	% TAKAGI SUGENO
	dof = dofprod(rls,mfs,trd(:,1:2));
	[p] = suglms([trd(:,1:2) ones(size(trd,1),1)],trd(:,3),dof);
else		% MAMDANI
	dof=dofmin(rls,mfs,trd(:,1:2));
	y=trd(:,3)*ones(1,size(dof,2));
	y=(sum(dof.*y))./(sum(dof)+1e-15);	% gives the singleton cons of all rules
	% Which pressure mfs corresps the most to the y's
	y=mgrade(y,mfsp);
	rmy=[];
	for i=1:size(y,2)
		index=find(y(:,i)==max(y(:,i)));
		rmy=[rmy;index(1)];
	end;
	rls=[rls,rmy];	% Mamdani rule base
end;
