function [mfs,ym,ylm,p,rls]=sinecl(x,y,mn,mt,ct,m,fh)
% [mfs,ym,ylm,p,rls]=sinecl(x,y,mn,mt,ct,m,fh)
% Sinus funtion fitting with clustering
% Sub-function called by fuzzCL
% x,y	Input-output data
% mn	number of clusters
% mt	membership fucntion type
% ct	Consequent type (1=singletons, 2=functional)
% m		fuzziness parameter
% fh	Figure handle (for plots)
%
% mfs	identified membership functions
% ym	model output
% ylm	Ylm ...	output of local submodels with data corresponding to
% 		degrees < 0.2 masked (for plots)
% p		consequent parameters
% rls	rule matrix
%
% See fuzzCL

% Magne Setnes, 18/5-98

% Make RLS matrix
rls=[ones(mn,1),[1:mn]'];

% Instruction widow
SCRSIZE = get(0,'screensize');
X = SCRSIZE(3); Y = SCRSIZE(4);
bsize=25;	%plot bar size
fsize=3;	%plot frame size
%--------------------------
% Open instructions window
%--------------------------
EditBckgrCol = [0.8 0.8 0.8];
pos=[0+fsize 2*Y/3+bsize X/2-2*fsize (Y/3)-bsize];
figNumber=figure( ...
	'NumberTitle','off', ...
        'Name','Instructions: Fuzzy Clustering', ...
        'Units','pixel', ...
        'Color',[0 0 0.5], ...
        'Visible','off', ...
	'Resize','on', ...
        'NextPlot','new', ...
        'Pointer','watch',...
	'Menu','none',...
	'Position',pos);
set(gca,'position',[0 0 1 1]);
axis off;
htext = text(0.1,0.9,'PLEASE WAIT');
htext = text(0.1,0.7,'Clustering the data...');
set(gcf,'Visible','on');

%%% Run CLUSTER-ALGO %%%
eps = 0.01; 	% termination criterion
if (ct==1);	% Consequents are singletons -> CMEANS
	[dof,p] = cmfuzz([x,y],mn,m,eps,fh);
	x_in=[];
	p=p(:,2);	%get cons from cluster centers
else,		% Linear consequents -> GK
	[dof,c,P,V] = gkfuzz([x,y],mn,m,eps,fh);
	p = [V(:,1) -sum((V(:,1:2).*c(:,1:2))')']./(-V(:,2)*ones(1,2));
    x_in=x;
end;

% Give new instruction
figure(figNumber);clf;axis off;
htext = text(0.1,0.9,'Press [ENTER] to fit');
htext = text(0.1,0.7,'parameterized membership functions');
htext = text(0.1,0.5,'to the projected clusters.');
pause on;pause;

% Make MFS
figure(fh);subplot(212);
cutoff = 0.1;
OPT = foptions; OPT(14) = 1000;

  [ds,fs]=smooth(x,dof,cutoff); 
  mf = mffit(ds,fs,mt,OPT,[1 1 1]);
  lim = mf(:,3) == min(mf(:,3)); mf(lim,2:3) = ones(sum(lim),1)*[min(x(:)) min(x(:))];
  if mf(lim,4) < min(x(:)), mf(lim,4) = min(x(:)); end;
  lim = mf(:,4) == max(mf(:,4)); mf(lim,4:5) = ones(sum(lim),1)*[max(x(:)) max(x(:))];
  if mf(lim,3) > max(x(:)), mf(lim,3) = max(x(:)); end;
  mfplot(ds',mf); 
  mfs = [mfs; mf];

% APPROXIMATION (model output)
[ym,yl,ylm] = sugval(p,[x_in, ones(size(y,1),1)],dof);

%%% PLOT RESULTS %%%
set(fh,'Color',[0 0 0.5]);
% Fit of function
figure(fh);
subplot(211);
plot(x,y,'b',x,ym,'r');axis([0 100 -50 60]);
set(gca,'box','off');
xlabel('x');ylabel('y_approx');

% Membership functions
subplot(212);
plot(x,mgrade(x',mfs));
xlabel('x');ylabel('Membership');
drawnow;

% Local models
figure(fh-1);
plot(x,y,'b');axis([0 100 min([ylm(find(ylm));y]) max([ylm(find(ylm));y])]);
set(gca,'box','off');hold on;
xlabel('x');ylabel('y');
plot(x,ylm,'g');
hold off;

% Close instruction window
close(figNumber); 
% end of function