function [ym,yl,ylm] = sugval(p,x,f,def)
% SUGVAL calculates the output of the Sugeno-Takagi model.
%
% [Ym,Yl,Ylm] = SUGVAL(P,X,F)
%    Input:
%       P .....	consequents parameters for every cluster
%               (obtained for instance with SUGLMS).
%       X ..... input data matrix.
%       F ..... fuzzy partition matrix (membership degrees
%               for all data points).
%       DEF ... default value returned when the sum of grades
%               equals to one (optional, defaults to 0)
%    Output:
%	Ym ....	global model output for the given input data
%	Yl ....	output of local submodels (corresponding to clusters)
%	Ylm ...	output of local submodels with data corresponding to
%		degrees < 0.2 masked (for plots)

% (c) Robert Babuska, January 1994

if nargin < 4, def = 0; end;              	% no default supplied
[mx,nx] = size(x); [mf,nf] = size(f);
sumDOF = sum([zeros(1,mf);f'])'*ones(1,nf);   	% sum of DOFs
NoRule = sumDOF == 0;                           % no rule applicable
sumDOF = sumDOF + NoRule;                       % set zeros to one
yl = x*p';                                      % local models
ym = sum([zeros(1,mx); ...
         (yl.*f./sumDOF)'])' + def.*NoRule(:,1); % global model
ylm = yl;
mask = find(f < 0.2);				% find membership degrees < 0.2
ylm(mask) = NaN*ones(size(mask));		% mask with NaN's for plots

