function txt = fuzz2txt(rls,inputs,outputs,nlab,labels);
% fuzz2TXT writes the rule base coded in a matrix into a string
% TXT = fuzz2TXT(RLS,INPUTS, OUTPUTS, NLAB, LABELS)
%
% Specially adopted from RLS2TXT for the fuzz Pressure Dynamics Exercise
%
% Inputs:     RLS       ...  rule-base matrix
%             INPUTS    ...  input labels
%             OUTPUTS   ...  output labels
%             NLAB      ...  number of labels for all inputs and outputs
%                            i.e. [i1; i2; i3; ... o1; o2; ...]
%             LABELS    ...  input and output labels concatenated in one
%                            matrix, i.e. [Input1_Label1; Input1_Label2;
%                                                       ...
%                                          Input2_Label1; Input2_Label2;
%                                                       ...
%                                          Output1_Label1; Output1_Label2;
%                                                       ...               ]
% % Output:     TXT       ...  text matrix
%

% (c) Robert Babuska, December 1993
% Adopted for fuzz by Magne Setnes, 1998

% directives and keywords
IfStr   = ' If '; ThenStr = ' then '; IsStr   = ' is ';
AndStr  = ' and '; NotStr  = ' not '; RuleEnd = '; ';
CSepStr = ', ';

[ninps,dummy] = size(inputs);
[nrules,nio] = size(rls);
w = rls(:,1); rls = rls(:,2:nio);
nouts = nio - ninps - 1;
nlab = nlab(:);
labind = [0; cumsum(nlab)];

txt = [];
for k = 1 : nrules,
  if any(w ~= 1), weight = sprintf('%4.2f',w(k));
  else weight = []; end
  rule = [mat2str(k) ':' weight IfStr];
  j = 0;
  for i = 1 : ninps
    if rls(k,i) ~= 0,
      j = j + 1;
      if j > 1, rule = [rule AndStr]; end;
      if rls(k,i) < 0; label = [NotStr labels(abs(rls(k,i)),:)];
      else label = labels(rls(k,i),:); end;
      rule = [rule inputs(i,:) IsStr label];
    end;
    if i == ninps, rule = [rule ThenStr]; end;
  end;
  j = 0;
  for i = 1 : nouts
    if rls(k,ninps+i) ~= 0 | nlab(ninps+i) == 0,
      j = j + 1;
      if j > 1, rule = [rule(1:length(rule)-1) CSepStr]; end;
      if nlab(ninps+i) ~= 0, cons = labels(rls(k,ninps+i),:);
      else cons = sprintf('%f',rls(k,ninps+i)); end;
      rule = [rule outputs(i,:) IsStr cons ' '];
    end;
  end;
  ind = find(rule == ' ');
  li = length(ind);
  rule(ind(find(ind(2:li)-ind(1:li-1) == 1))) = [];   % remove multiple blanks
  txt = str2mat(txt,[rule(1:length(rule)-1) RuleEnd]);
end;
txt(1,:) = [];
%txt(:,1)=[1:nrules]';
