% Function fitting exercise for fuzz Course, 1998
% Uses GK clustering
%
% Magne & Robert, 1998
% Matlab 5 version, September 1998

%--------------
%Load the data
%--------------
echo off;
clear all;close all;
load sinedata;

%------------
% Initialize
%------------
deffuzz;

mfs=mfequ(x,2,7);

%------------------------
% Plot data to be fitted
%------------------------
pos=urightsmall;
figNumber=1;figure(figNumber); clf;
set(figNumber,...
            'MenuBar','none','NextPlot','add', ...
            'Name','Function to approximate / local models','NumberTitle','off','Position',pos);
plot(x,y,'b');axis([0 100 -50 60]);
set(gca,'box','off');
xlabel('x');ylabel('y');

%---------------------
% Open the fit window
%----------------------
pos=lrightbig;
figNumber=2;figure(figNumber); clf;
set(figNumber,...
            'MenuBar','none','NextPlot','add', ...
            'Name','Approximation / membership functions','NumberTitle','off','Position',pos);
subplot(211),plot(x,y,'r');drawnow;	
axis([0 100 -50 60]);
set(gca,'box','off');
xlabel('x');ylabel('y approx');
subplot(212);
xlabel('x');ylabel('Membership');
htext = text(0.1,0.9,'Function Approximation and Clustering');
htext = text(0.1,0.7,'Magne and Robert');
htext = text(0.1,0.3,'DEFINE YOUR FUZZY SYSTEM');

%---------------------
% CONTROLS MENU
%----------------------
% Initialize important default values

MNStr='7';	% Default number of membership functions
MTStr='2';	% Default membership function type
CTStr='1';	% Default type of fuzzy system (1=singleton, 2=functions)
MStr='2';	% Default fuzziness
mn=7;
mt=2;
ct=1;
m=2;

pos=uleftsmall;
figNumber=figure( ...
	'NumberTitle','off', ...
        'Name','Fuzzy System- and Clustering Control Panel', ...
        'Units','pixel', ...
        'Visible','off', ...
		'Resize','on', ...
        'Pointer','watch',...
	'Menu','none',...
	'Position',pos);

set(gca,'position',[0 0 1 1]);
axis off;

% CONTROLS
%========================================

uicontrol( ...
        'Style','frame', ...
        'Units','normalized', ...
        'Position',[.75 .1 .2 .8]);

uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'Position',[0.76 .75 .18 .1], ...
	'HorizontalAlignment','center', ...
        'String','ACTIONS');

%========================================
% Create the CLUSTER button 

callbackStr=['mfs=clsine(x,y,mn,mt,ct,m,2);'];

uicontrol( ...
    'Interruptible','on', ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'UserData',0, ...
    'Position',[.77 .55 .16 .2], ...
    'String','CLUSTER', ...
    'Callback',callbackStr);

%=========================================
% Create the RE-CALCULATE button 

% mfs are identifed by clustering, but user can change mfs-type and consq.type
% this is taken into account by the RECALC button
% also new con. parameters are calculated by LS, while the cons. parameters  
% resulting from CLUST are taken from cluster cov.matrix
callbackStr=['mfs(:,1)=ones(size(mfs(:,1)))*mt;[ym,ylm,p]=clfit(x,y,ct,mfs,2);'];

uicontrol( ...
    'Interruptible','on', ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'UserData',0, ...
    'Position',[.77 .35 .16 .2], ...
    'String','RECALC', ...
    'Callback',callbackStr);

%========================================
% Create the EXIT button
callbackStr=[ ...
    'close all;clear;']; 
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',[.77 .15 .16 .2], ...
    'String','EXIT', ...
    'Callback',callbackStr);

% DATA FRAME

%---
uicontrol( ...
        'Style','frame', ...
        'Units','normalized', ...
        'Position',[.05 .1 .6 .8]);

uicontrol( ...
	'Style','text', ...
   'Units','normalized', ...
	'Position',[.25 .75 .2 .1], ...
        'HorizontalAlignment','center', ...
        'String','PARAMETERS');
%--- NUMBER OF CLUSTERS
uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'Position',[.1 .55 .4 .1], ...
        'HorizontalAlignment','left', ...
        'String','Number of Clusters (>1)');

uicontrol( ...
        'Style','edit', ...
        'Units','normalized', ...
        'String',MNStr, ...
        'Callback','MNStr = get(gco,''String''); mn = eval(MNStr);', ...
        'Position',[.55 .55 .07 .1]);
%--- FUZZINESS PARAMETER
uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'Position',[.1 .45 .4 .1], ...
        'HorizontalAlignment','left', ...
        'String','Fuzziness parameter (>1)');

uicontrol( ...
        'Style','edit', ...
        'Units','normalized', ...
        'String',MStr, ...
        'Callback','MStr = get(gco,''String''); m = eval(MStr); ', ...
        'Position',[.55 .45 .07 .1]);

%--- MFS TYPE
uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'Position',[.1 .35 .4 .1], ...
        'HorizontalAlignment','left', ...
        'String','Membership Func. Type (1,2,3)');

uicontrol( ...
        'Style','edit', ...
        'Units','normalized', ...
        'String',MTStr, ...
        'Callback','MTStr = get(gco,''String''); mt = eval(MTStr); ', ...
        'Position',[.55 .35 .07 .1]);

%---CONSEQUENT TYPE
uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'Position',[.1 .25 .3 .1], ...
        'HorizontalAlignment','left', ...
        'String','Consequent type (1,2)');

uicontrol( ...
        'Style','edit', ...
        'Units','normalized', ...
        'String',CTStr, ...
        'Callback','CTStr = get(gco,''String''); ct = eval(CTStr);', ...
        'Position',[.55 .25 .07 .1]);
uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'Position',[.1 .17 .5 .09], ...
        'HorizontalAlignment','left', ...
        'String','(Consequent 1 = sigleton)');
uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'Position',[.1 .11 .5 .09], ...
        'HorizontalAlignment','left', ...
        'String','(Consequent 2 = linear function)');		
		
set(gcf,'Visible','on','pointer','arrow');

